==> viha-5.15.tar.gz: viha-5.15/jarjesto.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "jarjesto";
$file = "jarjesto.php";

include "common.php";
include "jarjesto-ok.php";

echo "
<html>
<head>
 <title>VIHA - Jrjestt</title>
</head>
" . body_bgcolor() . "
<h1>Jrjestjen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$jarjesto = get_txt('jarjesto');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = jarjesto_add_ok($herja,$jarjesto,$alue_id,$paivystys_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
INSERT INTO jarjesto
SET jarjesto = '$jarjesto',
    alue_id = $alue_id,
    paivystys_id = $paivystys_id,
    ts = '$now'
";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "SISINEN";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = jarjesto_save_ok($herja,$id,$jarjesto,$alue_id,$paivystys_id);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE jarjesto
SET jarjesto='$jarjesto',
    alue_id = $alue_id,
    paivystys_id = $paivystys_id,
    ts='$now'
WHERE id=$id
";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = jarjesto_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM jarjesto WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = "0";
  $jarjesto = '';
  $alue_id = "1";
  $paivystys_id = "1";
}

# readonly tells if the fields are readonly. if not, they are editable.
# removable tells if we can actually remove this record
$readonly = 0;
if ($remove != '') {
  $readonly = 1;
  $removable = 0;
  $ret = jarjesto_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM jarjesto WHERE id = $id");
  $a = mysql_fetch_array($result);
  $jarjesto = $a['jarjesto'];
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
}

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Jrjest:";
if ($readonly) {
  echo "<td>$jarjesto\n";
} else {
  echo "<td><input type=\"text\" name=\"jarjesto\" size=64 maxlength=64";
  echo " value=\"$jarjesto\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("
SELECT jarjesto.id,jarjesto,jarjesto.ts,alue.alue,paivystys.nimi
FROM jarjesto,alue,paivystys
WHERE alue.id = jarjesto.alue_id AND paivystys.id = jarjesto.paivystys_id
ORDER BY alue,jarjesto
");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Operaatio<TH>Jrjest\n";
  while ($a = mysql_fetch_array($result)) {
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue; # just skip those items we do not have permission to
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[alue]",
      "<TD>$a[nimi]",
      "<TD>$a[jarjesto]";
    if (($id == "0") && ($a['id'] != "1")&& ($a['id'] != "2")) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<p>Plop. Ei jrjestj.\n";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: jarjesto.php,v 1.16 2009/03/25 20:18:13 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/jarjesto.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "jarjesto";
$file = "jarjesto.php";

include "common.php";
include "jarjesto-ok.php";

echo "
<html>
<head>
 <title>VIHA - Jrjestt</title>
</head>
" . body_bgcolor() . "
<h1>Jrjestjen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$jarjesto = get_txt('jarjesto');
$alue_id = get_nro_1('alue_id');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = jarjesto_add_ok($herja,$jarjesto,$alue_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO jarjesto
       SET jarjesto = '$jarjesto',
           alue_id = $alue_id,
           paivystys_id = 1,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    loki("$sql id=" . last_insert_id());
    $msg = "Listty jrjest $jarjesto";
    taktinen_loki($msg);
    tehty($msg);
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = jarjesto_save_ok($herja,$id,$jarjesto,$alue_id);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE jarjesto
       SET jarjesto='$jarjesto',
           alue_id = $alue_id,
           paivystys_id = 1,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Pivitetty jrjest $jarjesto";
    taktinen_loki($msg);
    tehty($msg);
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = jarjesto_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $msg = "Poistettu jrjest " . jarjesto($id);
    $sql = "DELETE FROM jarjesto WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    taktinen_loki($msg);
    tehty($msg);
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = "0";
  $jarjesto = '';
  $alue_id = "1";
}

# readonly tells if the fields are readonly. if not, they are editable.
# removable tells if we can actually remove this record
$readonly = 0;
if ($remove != '') {
  $readonly = 1;
  $removable = 0;
  $ret = jarjesto_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM jarjesto WHERE id = $id");
  $a = mysql_fetch_array($result);
  $jarjesto = $a['jarjesto'];
  $alue_id = $a['alue_id'];
}

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Jrjest:";
if ($readonly) {
  echo "<td>$jarjesto\n";
} else {
  echo "<td><input type=\"text\" name=\"jarjesto\" size=64 maxlength=64";
  echo " value=\"$jarjesto\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT jarjesto.id,jarjesto,jarjesto.ts,alue.alue
                  FROM jarjesto,alue
                  WHERE alue.id = jarjesto.alue_id
                  ORDER BY alue,jarjesto");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Jrjest\n";
  while ($a = mysql_fetch_array($result)) {
    if (visible_admin_tab($herja,$table,$a['id'],false) == 2)
      continue; # just skip those items we do not have permission to
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[alue]",
      "<TD>$a[jarjesto]";
    if (($id == "0") && ($a['id'] != "1")&& ($a['id'] != "2")) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<p>Plop. Ei jrjestj.\n";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: jarjesto.php,v 1.19 2009/10/05 11:03:16 riku Exp $ -->
